@@ -58,10 +58,10 @@ class MySQLDB(object):
             self.connection = MySQLdb.connect(host=host, port=port, user=user, passwd=passwd, db=db,charset='utf8')             
         
         #except MySQLdb.OperationalError:
-        except MySQLdb.OperationalError:
+        except MySQLdb.OperationalError as e:
             pwd = '...............' if len(passwd) > 0 else '<no password>'
-            raise ValueError('Cannot reach MySQL server with host:%s, port:%s, user:%s, pwd:%s, db:%s' %
-                             (host, port, user, pwd, db))
+            raise ValueError('Cannot reach MySQL server with host:%s, port:%s, user:%s, pwd:%s, db:%s (%s)' %
+                             (host, port, user, pwd, db, `e`))
         
     def dbName(self):
         '''
@@ -323,7 +323,8 @@ class MySQLDB(object):
     def query(self, queryStr):
         '''
         Query iterator. Given a query, return one result for each
-        subsequent call.
+        subsequent call. When all results have been retrieved,
+        the iterator returns None.
 
         :param queryStr: query
         :type queryStr: String
